@@ -13,10 +13,6 @@ The following transformations are supported:
  * AVRO -> JSON
 
 
-This package is compatible with Streaming Analytics service on IBM Cloud:
-
-  * `IBM Streaming Analytics <https://www.ibm.com/cloud/streaming-analytics>`_
-
 Sample
 ++++++
 
@@ -31,19 +27,20 @@ A simple example of a Streams application that serializes and deserializes messa
 
     avro_schema = '{"type" : "record", "name" : "hw_schema", "fields" : [{"name" : "a", "type" : "string"}]}'
     s = topo.source([{'a': 'Hello'}, {'a': 'World'}, {'a': '!'}]).as_json()
-        
     # convert json to avro blob
-    o = avro.json_to_avro(s, avro_schema)
+    o = s.map(avro.JSONToAvro(avro_schema))
     # convert avro blob to json
-    res = avro.avro_to_json(o, avro_schema)
+    res = o.map(avro.AvroToJSON(avro_schema))
     res.print()
 
     submit('STREAMING_ANALYTICS_SERVICE', topo)
+    # Use for IBM Streams including IBM Cloud Pak for Data
+    # submit ('DISTRIBUTED', topo, cfg)
 
 """
 
-__version__='1.0.0'
+__version__='1.2.2'
 
-__all__ = ['json_to_avro', 'avro_to_json']
-from streamsx.avro._avro import json_to_avro, avro_to_json
+__all__ = ['AvroToJSON', 'JSONToAvro', 'download_toolkit', 'json_to_avro', 'avro_to_json']
+from streamsx.avro._avro import download_toolkit, json_to_avro, avro_to_json, AvroToJSON, JSONToAvro
 
